/*!
 * @license
 * Copyright © 2005-2023 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { Category } from '@alfresco/js-api';
import { EventEmitter, OnDestroy, OnInit } from '@angular/core';
import { FormControl } from '@angular/forms';
import { Observable } from 'rxjs';
import { CategoriesManagementMode } from './categories-management-mode';
import { CategoryService } from '../services/category.service';
import * as i0 from "@angular/core";
interface CategoryNameControlErrors {
    duplicatedExistingCategory?: boolean;
    duplicatedCategory?: boolean;
    emptyCategory?: boolean;
    required?: boolean;
}
export declare class CategoriesManagementComponent implements OnInit, OnDestroy {
    private categoryService;
    readonly nameErrorMessagesByErrors: Map<keyof CategoryNameControlErrors, string>;
    private existingCategoryLoaded$;
    private cancelExistingCategoriesLoading$;
    private onDestroy$;
    private _categoryNameControl;
    private _existingCategories;
    private _categoryNameErrorMessageKey;
    private _existingCategoriesLoading;
    private _typing;
    private _existingCategoriesPanelVisible;
    private _categoryNameControlVisible;
    private readonly existingCategoriesListLimit;
    initialCategories: Category[];
    noCategoriesMsg: string;
    removeCategoryTitle: string;
    existingCategoriesMsg: string;
    /** Categories to display initially */
    categories: Category[];
    /**
     * Decides if categoryNameControl should be visible. Sets also existing categories panel visibility
     * and scrolls control into view when visible.
     *
     * @param categoryNameControlVisible control visibility.
     */
    set categoryNameControlVisible(categoryNameControlVisible: boolean);
    get categoryNameControlVisible(): boolean;
    /** Emits when classifiable aspect changes */
    classifiableChanged: Observable<void>;
    /** Disables remove button in upper categories list */
    disableRemoval: boolean;
    /**
     * Component mode.
     * In ASSIGN mode we can only assign/unassign categories from existing list.
     * In CRUD mode we can create categories.
     */
    managementMode: CategoriesManagementMode;
    /** ID of a parent category. New categories will be created under this parent */
    parentId: string;
    /** Emits when state of upper categories list changes */
    categoriesChange: EventEmitter<Category[]>;
    /** Emits when categoryNameControl visibility changes */
    categoryNameControlVisibleChange: EventEmitter<boolean>;
    private categoryNameInputElement;
    constructor(categoryService: CategoryService);
    ngOnInit(): void;
    ngOnDestroy(): void;
    get categoryNameControl(): FormControl<string>;
    get showEmptyCategoryMessage(): boolean;
    get existingCategories(): Category[];
    get categoryNameErrorMessageKey(): string;
    get existingCategoriesLoading(): boolean;
    get typing(): boolean;
    get existingCategoriesPanelVisible(): boolean;
    get isCRUDMode(): boolean;
    /**
     * Adds category that has been typed to a categoryNameControl and hides it afterwards.
     */
    addCategory(): void;
    /**
     * Adds existing category to categories list and removes it from existing categories list.
     *
     * @param category - selection list change containing selected category
     */
    addCategoryToAssign(category: Category): void;
    /**
     * Removes the category from categories list and adds it to existing categories list in ASSIGN mode.
     *
     * @param category - category to remove
     */
    removeCategory(category: Category): void;
    private onNameControlValueChange;
    private searchForExistingCategories;
    private getChildrenCategories;
    private validateIfNotAlreadyAdded;
    private validateIfNotAlreadyCreated;
    private compareCategories;
    private validateEmptyCategory;
    private setCategoryNameControlErrorMessageKey;
    private sortCategoriesList;
    private clearCategoryNameInput;
    static ɵfac: i0.ɵɵFactoryDeclaration<CategoriesManagementComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<CategoriesManagementComponent, "adf-categories-management", never, { "categories": "categories"; "categoryNameControlVisible": "categoryNameControlVisible"; "classifiableChanged": "classifiableChanged"; "disableRemoval": "disableRemoval"; "managementMode": "managementMode"; "parentId": "parentId"; }, { "categoriesChange": "categoriesChange"; "categoryNameControlVisibleChange": "categoryNameControlVisibleChange"; }, never, never, false>;
}
export {};
