import { NodeEntry, NodePaging, NodesApi, TrashcanApi, Node } from '@alfresco/js-api';
import { Subject, Observable } from 'rxjs';
import { AlfrescoApiService, UserPreferencesService } from '@alfresco/adf-core';
import { NodeMetadata } from '../models/node-metadata.model';
import * as i0 from "@angular/core";
export declare class NodesApiService {
    private apiService;
    private preferences;
    /**
     * Publish/subscribe to events related to node updates.
     */
    nodeUpdated: Subject<Node>;
    private _trashcanApi;
    get trashcanApi(): TrashcanApi;
    private _nodesApi;
    get nodesApi(): NodesApi;
    constructor(apiService: AlfrescoApiService, preferences: UserPreferencesService);
    private getEntryFromEntity;
    /**
     * Gets the stored information about a node.
     *
     * @param nodeId ID of the target node
     * @param options Optional parameters supported by JS-API
     * @returns Node information
     */
    getNode(nodeId: string, options?: any): Observable<Node>;
    /**
     * Gets the items contained in a folder node.
     *
     * @param nodeId ID of the target node
     * @param options Optional parameters supported by JS-API
     * @returns List of child items from the folder
     */
    getNodeChildren(nodeId: string, options?: any): Observable<NodePaging>;
    /**
     * Creates a new document node inside a folder.
     *
     * @param parentNodeId ID of the parent folder node
     * @param nodeBody Data for the new node
     * @param options Optional parameters supported by JS-API
     * @returns Details of the new node
     */
    createNode(parentNodeId: string, nodeBody: any, options?: any): Observable<Node>;
    /**
     * Creates a new folder node inside a parent folder.
     *
     * @param parentNodeId ID of the parent folder node
     * @param nodeBody Data for the new folder
     * @param options Optional parameters supported by JS-API
     * @returns Details of the new folder
     */
    createFolder(parentNodeId: string, nodeBody: any, options?: any): Observable<Node>;
    /**
     * Updates the information about a node.
     *
     * @param nodeId ID of the target node
     * @param nodeBody New data for the node
     * @param options Optional parameters supported by JS-API
     * @returns Updated node information
     */
    updateNode(nodeId: string, nodeBody: any, options?: any): Observable<Node>;
    /**
     * Moves a node to the trashcan.
     *
     * @param nodeId ID of the target node
     * @param options Optional parameters supported by JS-API
     * @returns Empty result that notifies when the deletion is complete
     */
    deleteNode(nodeId: string, options?: any): Observable<any>;
    /**
     * Restores a node previously moved to the trashcan.
     *
     * @param nodeId ID of the node to restore
     * @returns Details of the restored node
     */
    restoreNode(nodeId: string): Observable<Node>;
    /**
     * Get the metadata and the nodeType for a nodeId cleaned by the prefix.
     *
     * @param nodeId ID of the target node
     * @returns Node metadata
     */
    getNodeMetadata(nodeId: string): Observable<NodeMetadata>;
    /**
     * Create a new Node from form metadata.
     *
     * @param nodeType Node type
     * @param nameSpace Namespace for properties
     * @param data Property data to store in the node under namespace
     * @param path Path to the node
     * @param name Node name
     * @returns The created node
     */
    createNodeMetadata(nodeType: string, nameSpace: any, data: any, path: string, name?: string): Observable<NodeEntry>;
    private randomNodeName;
    /**
     * Gets content for the given node.
     *
     * @param nodeId ID of the target node
     * @returns Content data
     */
    getNodeContent(nodeId: string): Observable<any>;
    /**
     * Create a new Node inside `-root-` folder
     *
     * @param name Node name
     * @param nodeType Node type
     * @param properties Node body properties
     * @param path Path to the node
     * @returns The created node
     */
    createNodeInsideRoot(name: string, nodeType: string, properties: any, path: string): Observable<NodeEntry>;
    private cleanMetadataFromSemicolon;
    static ɵfac: i0.ɵɵFactoryDeclaration<NodesApiService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<NodesApiService>;
}
