/*!
 * @license
 * Copyright © 2005-2023 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { OnChanges, SimpleChanges } from '@angular/core';
import { Node } from '@alfresco/js-api';
import { NodeAspectService } from '../../../aspect-list/services/node-aspect.service';
import { ContentMetadataCustomPanel, PresetConfig } from '../../interfaces/content-metadata.interfaces';
import { VersionCompatibilityService } from '../../../version-compatibility/version-compatibility.service';
import { ContentService } from '../../../common/services/content.service';
import * as i0 from "@angular/core";
export declare class ContentMetadataCardComponent implements OnChanges {
    private contentService;
    private nodeAspectService;
    private versionCompatibilityService;
    /** (required) The node entity to fetch metadata about */
    node: Node;
    /**
     * This flag displays/hides empty metadata
     * fields.
     */
    displayEmpty?: boolean;
    /**
     * This flag displays desired aspect when open for the first time fields.
     */
    displayAspect?: string;
    /** Display tags in the card */
    displayTags: boolean;
    /** Display categories in the card */
    displayCategories: boolean;
    /**
     * Name or configuration of the metadata preset, which defines aspects
     * and their properties.
     */
    preset: string | PresetConfig;
    /**
     * This flag sets the metadata in read only mode preventing changes.
     */
    readOnly?: boolean;
    /**
     * This flag allows the component to display more
     * than one accordion at a time.
     */
    multi?: boolean;
    /** This flag toggles editable of content. */
    editable?: boolean;
    /** List of custom metadata panels to be displayed with registered custom components */
    customPanels: ContentMetadataCustomPanel[];
    private _displayDefaultProperties;
    /**
     * This flag displays/hides the metadata properties.
     */
    set displayDefaultProperties(value: boolean);
    get displayDefaultProperties(): boolean;
    expanded: boolean;
    editAspectSupported: boolean;
    constructor(contentService: ContentService, nodeAspectService: NodeAspectService, versionCompatibilityService: VersionCompatibilityService);
    ngOnChanges(changes: SimpleChanges): void;
    onDisplayDefaultPropertiesChange(): void;
    hasAllowableOperations(): boolean;
    openAspectDialog(): void;
    isEditAspectSupported(): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<ContentMetadataCardComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ContentMetadataCardComponent, "adf-content-metadata-card", never, { "node": "node"; "displayEmpty": "displayEmpty"; "displayAspect": "displayAspect"; "displayTags": "displayTags"; "displayCategories": "displayCategories"; "preset": "preset"; "readOnly": "readOnly"; "multi": "multi"; "editable": "editable"; "customPanels": "customPanels"; "displayDefaultProperties": "displayDefaultProperties"; }, {}, never, never, false>;
}
