/*!
 * @license
 * Copyright © 2005-2023 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { OnInit, OnDestroy } from '@angular/core';
import { MatDialog, MatDialogRef } from '@angular/material/dialog';
import { MatSlideToggleChange } from '@angular/material/slide-toggle';
import { FormControl, FormGroup } from '@angular/forms';
import { ContentService } from '../common/services/content.service';
import { SharedLinksApiService } from './services/shared-links-api.service';
import { ContentNodeShareSettings } from './content-node-share.settings';
import { RenditionService } from '../common/services/rendition.service';
import * as i0 from "@angular/core";
interface SharedDialogFormProps {
    sharedUrl: FormControl<string>;
    time: FormControl<Date>;
}
export declare class ShareDialogComponent implements OnInit, OnDestroy {
    private sharedLinksApiService;
    private dialogRef;
    private dialog;
    private contentService;
    private renditionService;
    data: ContentNodeShareSettings;
    private minDateValidator;
    minDate: Date;
    sharedId: string;
    fileName: string;
    baseShareUrl: string;
    isFileShared: boolean;
    isDisabled: boolean;
    isLinkWithExpiryDate: boolean;
    form: FormGroup<SharedDialogFormProps>;
    isExpiryDateToggleChecked: boolean;
    slideToggleExpirationDate: any;
    private onDestroy$;
    constructor(sharedLinksApiService: SharedLinksApiService, dialogRef: MatDialogRef<ShareDialogComponent>, dialog: MatDialog, contentService: ContentService, renditionService: RenditionService, data: ContentNodeShareSettings);
    ngOnInit(): void;
    onTimeChanged(): void;
    get time(): FormControl<Date>;
    ngOnDestroy(): void;
    onSlideShareChange(event: MatSlideToggleChange): void;
    get canUpdate(): boolean;
    onToggleExpirationDate(slideToggle: MatSlideToggleChange): void;
    onDatePickerClosed(): void;
    preventIncorrectCharacters(e: KeyboardEvent): boolean;
    private openConfirmationDialog;
    private createSharedLinks;
    deleteSharedLink(sharedId: string, dialogOpenFlag?: boolean): void;
    private handleError;
    private updateForm;
    private updateNode;
    private sharedLinkWithExpirySettings;
    private updateEntryExpiryDate;
    static ɵfac: i0.ɵɵFactoryDeclaration<ShareDialogComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ShareDialogComponent, "adf-share-dialog", never, {}, {}, never, never, false>;
}
export {};
