/*!
 * @license
 * Copyright © 2005-2023 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { IdentityUserModel, UserInfoMode } from '@alfresco/adf-core';
import { OnDestroy } from '@angular/core';
import { MatMenuTrigger, MenuPositionX, MenuPositionY } from '@angular/material/menu';
import { EcmUserModel } from '../common/models/ecm-user.model';
import { PeopleContentService } from '../common/services/people-content.service';
import * as i0 from "@angular/core";
export declare class ContentUserInfoComponent implements OnDestroy {
    private peopleContentService;
    trigger: MatMenuTrigger;
    /** Determines if user is logged in. */
    isLoggedIn: boolean;
    /** ECM user info. */
    ecmUser: EcmUserModel;
    /** Identity user info. */
    identityUser: IdentityUserModel;
    /** current mode. */
    mode: UserInfoMode;
    /** Custom path for the background banner image for ACS users. */
    ecmBackgroundImage: string;
    /** Custom path for the background banner image for APS users. */
    bpmBackgroundImage: string;
    /** Custom choice for opening the menu at the bottom. Can be `before` or `after`. */
    menuPositionX: MenuPositionX;
    /** Custom choice for opening the menu at the bottom. Can be `above` or `below`. */
    menuPositionY: MenuPositionY;
    /** Shows/hides the username next to the user info button. */
    showName: boolean;
    /**
     * When the username is shown, this defines its position relative to the user info button.
     * Can be `right` or `left`.
     */
    namePosition: string;
    userInfoMode: typeof UserInfoMode;
    private destroy$;
    constructor(peopleContentService: PeopleContentService);
    ngOnDestroy(): void;
    onKeyPress(event: KeyboardEvent): void;
    private closeUserModal;
    stopClosing(event: Event): void;
    getEcmAvatar(avatarId: string): string;
    get showOnRight(): boolean;
    get canShow(): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<ContentUserInfoComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ContentUserInfoComponent, "adf-content-user-info", never, { "isLoggedIn": "isLoggedIn"; "ecmUser": "ecmUser"; "identityUser": "identityUser"; "mode": "mode"; "ecmBackgroundImage": "ecmBackgroundImage"; "bpmBackgroundImage": "bpmBackgroundImage"; "menuPositionX": "menuPositionX"; "menuPositionY": "menuPositionY"; "showName": "showName"; "namePosition": "namePosition"; }, {}, never, never, false>;
}
