/*!
 * @license
 * Copyright © 2005-2023 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { Subject } from 'rxjs';
import { OnInit, EventEmitter, OnDestroy } from '@angular/core';
import { UntypedFormBuilder, UntypedFormGroup } from '@angular/forms';
import { MatDialogRef } from '@angular/material/dialog';
import { QueriesApi } from '@alfresco/js-api';
import { AlfrescoApiService, NotificationService } from '@alfresco/adf-core';
import { SitesService } from '../../common/services/sites.service';
import * as i0 from "@angular/core";
export declare class LibraryDialogComponent implements OnInit, OnDestroy {
    private alfrescoApiService;
    private sitesService;
    private formBuilder;
    private dialog;
    private notificationService;
    /** Emitted when an error occurs. */
    error: EventEmitter<any>;
    /**
     * Emitted when the new library is created successfully. The
     * event parameter is a SiteEntry object with the details of the
     * newly-created library.
     */
    success: EventEmitter<any>;
    onDestroy$: Subject<boolean>;
    createTitle: string;
    libraryTitleExists: boolean;
    form: UntypedFormGroup;
    visibilityOption: any;
    visibilityOptions: {
        value: string;
        label: string;
        disabled: boolean;
    }[];
    disableCreateButton: boolean;
    _queriesApi: QueriesApi;
    get queriesApi(): QueriesApi;
    constructor(alfrescoApiService: AlfrescoApiService, sitesService: SitesService, formBuilder: UntypedFormBuilder, dialog: MatDialogRef<LibraryDialogComponent>, notificationService: NotificationService);
    ngOnInit(): void;
    ngOnDestroy(): void;
    get title(): string;
    get id(): string;
    get description(): string;
    get visibility(): string;
    submit(): void;
    visibilityChangeHandler(event: any): void;
    private create;
    private sanitize;
    private canGenerateId;
    private handleError;
    private checkLibraryNameExists;
    private findLibraryByTitle;
    private forbidSpecialCharacters;
    private forbidOnlySpaces;
    private createSiteIdValidator;
    static ɵfac: i0.ɵɵFactoryDeclaration<LibraryDialogComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<LibraryDialogComponent, "adf-library-dialog", never, {}, { "error": "error"; "success": "success"; }, never, never, false>;
}
