/*!
 * @license
 * Copyright © 2005-2023 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { EventEmitter, OnChanges, SimpleChanges } from '@angular/core';
import { SiteEntry, SitesApi } from '@alfresco/js-api';
import { BehaviorSubject } from 'rxjs';
import { AlfrescoApiService } from '@alfresco/adf-core';
import { LibraryMembershipToggleEvent } from '../interfaces/library-membership-toggle-event.interface';
import { LibraryMembershipErrorEvent } from '../interfaces/library-membership-error-event.interface';
import { VersionCompatibilityService } from '../version-compatibility/version-compatibility.service';
import { SitesService } from '../common/services/sites.service';
import * as i0 from "@angular/core";
export declare class LibraryMembershipDirective implements OnChanges {
    private alfrescoApiService;
    private sitesService;
    private versionCompatibilityService;
    targetSite: any;
    isJoinRequested: BehaviorSubject<boolean>;
    private _sitesApi;
    get sitesApi(): SitesApi;
    /** Site for which to toggle the membership request. */
    selection: SiteEntry;
    /** Site for which to toggle the membership request. */
    isAdmin: boolean;
    toggle: EventEmitter<LibraryMembershipToggleEvent>;
    error: EventEmitter<LibraryMembershipErrorEvent>;
    onClick(): void;
    constructor(alfrescoApiService: AlfrescoApiService, sitesService: SitesService, versionCompatibilityService: VersionCompatibilityService);
    ngOnChanges(changes: SimpleChanges): void;
    toggleMembershipRequest(): void;
    markMembershipRequest(): void;
    private joinLibraryRequest;
    private joinLibrary;
    private cancelJoinRequest;
    private getMembershipRequest;
    static ɵfac: i0.ɵɵFactoryDeclaration<LibraryMembershipDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<LibraryMembershipDirective, "[adf-library-membership]", ["libraryMembership"], { "selection": "adf-library-membership"; "isAdmin": "isAdmin"; }, { "toggle": "toggle"; "error": "error"; }, never, never, false>;
}
