/*!
 * @license
 * Copyright © 2005-2023 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { AlfrescoApiService, CommentModel, CommentsService } from '@alfresco/adf-core';
import { CommentsApi } from '@alfresco/js-api';
import { Observable } from 'rxjs';
import { ContentService } from '../../common/services/content.service';
import * as i0 from "@angular/core";
export declare class NodeCommentsService implements CommentsService {
    private apiService;
    private contentService;
    private _commentsApi;
    get commentsApi(): CommentsApi;
    constructor(apiService: AlfrescoApiService, contentService: ContentService);
    /**
     * Gets all comments that have been added to a task.
     *
     * @param id ID of the target task
     * @returns Details for each comment
     */
    get(id: string): Observable<CommentModel[]>;
    /**
     * Adds a comment to a task.
     *
     * @param id ID of the target task
     * @param message Text for the comment
     * @returns Details about the comment
     */
    add(id: string, message: string): Observable<CommentModel>;
    private addToComments;
    private newCommentModel;
    getUserImage(avatarId: string): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<NodeCommentsService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<NodeCommentsService>;
}
