/*!
 * @license
 * Copyright © 2005-2023 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { Node, PermissionElement } from '@alfresco/js-api';
import { MatDialog } from '@angular/material/dialog';
import { Observable } from 'rxjs';
import { NodePermissionService } from './node-permission.service';
import { RoleModel } from '../models/role.model';
import { ContentService } from '../../common/services/content.service';
import * as i0 from "@angular/core";
export declare class NodePermissionDialogService {
    private dialog;
    private nodePermissionService;
    private contentService;
    constructor(dialog: MatDialog, nodePermissionService: NodePermissionService, contentService: ContentService);
    /**
     * Opens a dialog to add permissions to a node.
     *
     * @param node target node
     * @param roles settable roles for the node
     * @param title Dialog title
     * @returns Node with updated permissions
     */
    openAddPermissionDialog(node: Node, roles: RoleModel[], title?: string): Observable<PermissionElement[]>;
    private openDialog;
    /**
     * Closes the currently-open dialog.
     */
    close(): void;
    /**
     * Opens a dialog to update permissions for a node.
     *
     * @param nodeId ID of the target node
     * @param title Dialog title
     * @returns Node with updated permissions
     */
    updateNodePermissionByDialog(nodeId?: string, title?: string): Observable<Node>;
    static ɵfac: i0.ɵɵFactoryDeclaration<NodePermissionDialogService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<NodePermissionDialogService>;
}
