/*!
 * @license
 * Copyright © 2005-2023 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
export declare class SearchFilterList<T> implements Iterable<T> {
    private filteredItems;
    private _filterText;
    items: T[];
    pageSize: number;
    currentPageSize: number;
    get filterText(): string;
    set filterText(value: string);
    private _filter;
    get filter(): (item: T) => boolean;
    set filter(value: (item: T) => boolean);
    private applyFilter;
    /**
     * Returns visible portion of the items.
     *
     * @returns list of items
     */
    get visibleItems(): T[];
    /**
     * Get items length
     *
     * @returns entire collection length including items not displayed on the page
     */
    get length(): number;
    /**
     * Detect whether more items can be displayed.
     *
     * @returns `true` if can show more items, otherwise `false`
     */
    get canShowMoreItems(): boolean;
    /**
     * Detect whether less items can be displayed.
     *
     * @returns `true` if can show less items, otherwise `false`
     */
    get canShowLessItems(): boolean;
    /**
     * Detect whether content fits single page.
     *
     * @returns `true` if content fits single page, otherwise `false`.
     */
    get fitsPage(): boolean;
    constructor(items?: T[], pageSize?: number);
    /** Display more items. */
    showMoreItems(): void;
    /** Display less items. */
    showLessItems(): void;
    /** Reset entire collection and page settings. */
    clear(): void;
    addItem(item: T): void;
    deleteItem(item: T): void;
    [Symbol.iterator](): Iterator<T>;
}
