/*!
 * @license
 * Copyright © 2005-2023 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { OnDestroy } from '@angular/core';
import { FacetField } from '../models/facet-field.interface';
import { SearchQueryBuilderService } from './search-query-builder.service';
import { TranslationService } from '@alfresco/adf-core';
import { SearchService } from './search.service';
import { FacetFieldBucket } from '../models/facet-field-bucket.interface';
import { CategoryService } from '../../category/services/category.service';
import { TabbedFacetField } from '../models/tabbed-facet-field.interface';
import * as i0 from "@angular/core";
export interface SelectedBucket {
    field: FacetField;
    bucket: FacetFieldBucket;
}
export declare class SearchFacetFiltersService implements OnDestroy {
    queryBuilder: SearchQueryBuilderService;
    private searchService;
    private translationService;
    private categoryService;
    /**
     * All facet field items to be displayed in the component. These are updated according to the response.
     * When a new search is performed, the already existing items are updated with the new bucket count values and
     * the newly received items are added to the responseFacets.
     */
    responseFacets: FacetField[];
    tabbedFacet: TabbedFacetField;
    /** shows the facet chips */
    selectedBuckets: SelectedBucket[];
    private readonly facetQueriesPageSize;
    private readonly onDestroy$;
    constructor(queryBuilder: SearchQueryBuilderService, searchService: SearchService, translationService: TranslationService, categoryService: CategoryService);
    onDataLoaded(data: any): void;
    private parseFacets;
    private parseFacetItems;
    private parseTabbedFacetField;
    private extractCreatorAndModifier;
    private parseFacetFields;
    private parseFacetIntervals;
    private parseFacetQueries;
    private sortFacets;
    private getResponseBuckets;
    private getResponseQueryBuckets;
    private sortFacetBuckets;
    private getCountValue;
    getBucketCountDisplay(bucket: FacetFieldBucket): string;
    private getFilterByMinCount;
    private getCorrespondingFilterQuery;
    private buildIntervalQuery;
    private findFacet;
    private findResponseFacet;
    private updateExistingBuckets;
    private getBucketFilterFunction;
    private loadCategoryNames;
    unselectFacetBucket(facetField: FacetField, bucket: FacetFieldBucket): void;
    updateSelectedBuckets(): void;
    ngOnDestroy(): void;
    resetAllSelectedBuckets(): void;
    resetQueryFragments(): void;
    reset(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<SearchFacetFiltersService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SearchFacetFiltersService>;
}
