import { Observable, Subject } from 'rxjs';
import { SecurityControlsGroupResponse } from './models/security-controls-group-response.interface';
import { SecurityControlsMarkResponse } from './models/security-controls-mark-response.interface';
import { SecurityGroupsApi, SecurityMarksApi, SecurityGroupEntry, SecurityMarkEntry, SecurityGroupBody, SecurityMarkPaging, SecurityMarkBody, AuthorityClearanceApi, AuthorityClearanceGroupPaging, NodeSecurityMarkBody } from '@alfresco/js-api';
import { AlfrescoApiService, UserPreferencesService } from '@alfresco/adf-core';
import * as i0 from "@angular/core";
export declare class SecurityControlsService {
    private apiService;
    private userPreferencesService;
    private groupsPaginatedSource;
    groupsPaginated$: Observable<SecurityControlsGroupResponse>;
    private reloadSecurityControls;
    reloadSecurityControls$: Observable<void>;
    private _reloadAuthorityClearance;
    reloadAuthorityClearance$: Observable<void>;
    private marksPaginatedSource;
    marksPaginated$: Observable<SecurityControlsMarkResponse>;
    private loadingSource;
    loading$: Observable<boolean>;
    private securityGroup;
    private securityMark;
    private authorityClearance;
    constructor(apiService: AlfrescoApiService, userPreferencesService: UserPreferencesService);
    get groupsApi(): SecurityGroupsApi;
    get marksApi(): SecurityMarksApi;
    get authorityClearanceApi(): AuthorityClearanceApi;
    get reloadAuthorityClearance(): Subject<void>;
    /**
     * Get All security groups
     *
     * @param skipCount The number of entities that exist in the collection before those included in this list.
     * @param maxItems The maximum number of items to return in the list. Default is specified by UserPreferencesService.
     * @param include Additional information about the security group
     * @returns Promise<SecurityControlsGroupResponse>
     */
    getSecurityGroup(skipCount?: number, maxItems?: number, include?: string): Promise<SecurityControlsGroupResponse>;
    /**
     * Create security group
     *
     * @param input securityGroupBody.
     * @returns Observable<SecurityGroupEntry>
     */
    createSecurityGroup(input: SecurityGroupBody): Observable<SecurityGroupEntry>;
    /**
     * Create security marks
     *
     * @param securityGroupId The key for the security group id.
     * @param input securityMarkBody[].
     * @returns Promise<SecurityMarkPaging | SecurityMarkEntry>
     */
    createSecurityMarks(securityGroupId: string, input: SecurityMarkBody[]): Promise<SecurityMarkPaging | SecurityMarkEntry>;
    /**
     * Get security mark value
     * Gets the value for a selected **securityGroupId**.
     *
     * @param securityGroupId The key for the security group id.
     * @param skipCount The number of entities that exist in the collection before those included in this list.
     * @returns Promise<SecurityControlsMarkResponse>
     */
    getSecurityMark(securityGroupId: string, skipCount?: number): Promise<SecurityControlsMarkResponse>;
    /**
     * Update a security groups information
     *
     * @param securityGroupId The Key of Security Group id for which info is required
     * @param input SecurityGroupBody
     * @param opts additional information about the security group
     * @returns Promise<SecurityGroupEntry>
     */
    updateSecurityGroup(securityGroupId: string, input: SecurityGroupBody, opts?: any): Promise<SecurityGroupEntry>;
    /**
     * Updates Security Mark value
     *
     * @param securityGroupId The key for the security group id.
     * @param securityMarkId The key for the security mark is in use or not.
     * @param input securityMarkBody.
     * @returns Promise<SecurityMarkEntry>
     */
    updateSecurityMark(securityGroupId: string, securityMarkId: string, input: SecurityMarkBody): Promise<SecurityMarkEntry>;
    /**
     * Delete security group
     *
     * @param securityGroupId The key for the security group id.
     * @returns Observable<void>
     */
    deleteSecurityGroup(securityGroupId: string): Observable<void>;
    /**
     * Delete security mark
     *
     * @param securityGroupId The key for the security group id.
     * @param securityMarkId The key for the security mark id.
     * @returns Promise<SecurityMarkEntry>
     */
    deleteSecurityMark(securityGroupId: string, securityMarkId: string): Promise<SecurityMarkEntry>;
    /**
     * Get the authority clearances for a single user/group
     *
     * @param authorityName The name for the authority for which the clearance is to be fetched. Can be left blank in which case it will fetch it for all users with pagination
     * @param skipCount The number of entities that exist in the collection before those included in this list.
     * @param maxItems The maximum number of items to return in the list. Default is specified by UserPreferencesService.
     * @returns Observable<AuthorityClearanceGroupPaging>
     */
    getClearancesForAuthority(authorityName: string, skipCount?: number, maxItems?: number): Observable<AuthorityClearanceGroupPaging>;
    /**
     * Updates the authority clearance.
     *
     * @param authorityName The name for the authority for which the clearance is to be updated
     * @param securityMarksList NodeSecurityMarkBody[]
     * @returns Observable<SecurityMarkEntry | SecurityMarkPaging>
     */
    updateClearancesForAuthority(authorityName: string, securityMarksList: NodeSecurityMarkBody[]): Observable<SecurityMarkEntry | SecurityMarkPaging>;
    reloadSecurityGroups(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<SecurityControlsService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SecurityControlsService>;
}
