/*!
 * @license
 * Copyright © 2005-2023 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { UserPreferencesService } from '@alfresco/adf-core';
import { ChangeDetectorRef, EventEmitter, OnDestroy, OnInit, ElementRef } from '@angular/core';
import { FileUploadingListComponent } from './file-uploading-list.component';
import { UploadService } from '../../common/services/upload.service';
import { FileModel } from '../../common/models/file.model';
import * as i0 from "@angular/core";
export declare class FileUploadingDialogComponent implements OnInit, OnDestroy {
    private uploadService;
    private changeDetector;
    private userPreferencesService;
    private elementRef;
    /** Dialog direction. Can be 'ltr' or 'rtl. */
    private direction;
    private onDestroy$;
    uploadList: FileUploadingListComponent;
    /** Dialog position. Can be 'left' or 'right'. */
    position: string;
    /** Makes the dialog always visible even when there are no uploads. */
    alwaysVisible: boolean;
    /** Emitted when a file in the list has an error. */
    error: EventEmitter<any>;
    get isPositionRight(): boolean;
    get isPositionLeft(): boolean;
    filesUploadingList: FileModel[];
    isDialogActive: boolean;
    totalCompleted: number;
    totalErrors: number;
    isDialogMinimized: boolean;
    isConfirmation: boolean;
    private listSubscription;
    private counterSubscription;
    private fileUploadSubscription;
    private errorSubscription;
    private dialogActive;
    constructor(uploadService: UploadService, changeDetector: ChangeDetectorRef, userPreferencesService: UserPreferencesService, elementRef: ElementRef);
    ngOnInit(): void;
    /**
     * Toggle confirmation message.
     */
    toggleConfirmation(): void;
    /**
     * Cancel uploads and hide confirmation
     */
    cancelAllUploads(): void;
    /**
     * Toggle dialog minimized state.
     */
    toggleMinimized(): void;
    /**
     * Dismiss dialog
     */
    close(): void;
    ngOnDestroy(): void;
    canShowDialog(): boolean;
    canShowCancelAll(): boolean;
    canCloseDialog(): boolean;
    hasUploadInProgress(): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<FileUploadingDialogComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<FileUploadingDialogComponent, "adf-file-uploading-dialog", never, { "position": "position"; "alwaysVisible": "alwaysVisible"; }, { "error": "error"; }, never, never, false>;
}
