/*!
 * @license
 * Copyright © 2005-2023 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { TranslationService } from '@alfresco/adf-core';
import { UploadService } from '../../common/services/upload.service';
import { FileModel } from '../../common/models/file.model';
import { EventEmitter } from '@angular/core';
import * as i0 from "@angular/core";
export declare class FileUploadingListComponent {
    private uploadService;
    private translateService;
    template: any;
    files: FileModel[];
    /** Emitted when a file in the list has an error. */
    error: EventEmitter<any>;
    constructor(uploadService: UploadService, translateService: TranslationService);
    /**
     * Cancel file upload
     *
     * @param file File model to cancel upload for.
     */
    cancelFile(file: FileModel): void;
    /**
     * Remove uploaded file
     *
     * @param file File model to remove upload for.
     */
    removeFile(file: FileModel): void;
    /**
     * Calls the appropriate methods for each file, depending on state
     */
    cancelAllFiles(): void;
    /**
     * Checks if all the files are uploaded false if there is at least one file in Progress | Starting | Pending
     *
     * @returns `true` if upload is complete, otherwise `false`
     */
    isUploadCompleted(): boolean;
    /**
     * Check if all the files are Cancelled | Aborted | Error. false if there is at least one file in uploading states
     *
     * @returns `true` if upload is cancelled, otherwise `false`
     */
    isUploadCancelled(): boolean;
    private cancelNodeVersionInstances;
    private notifyError;
    private isUploadingFile;
    static ɵfac: i0.ɵɵFactoryDeclaration<FileUploadingListComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<FileUploadingListComponent, "adf-file-uploading-list", never, { "files": "files"; }, { "error": "error"; }, ["template"], never, false>;
}
