/*!
 * @license
 * Copyright © 2005-2023 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { LogService } from '@alfresco/adf-core';
import { EventEmitter, OnChanges, OnInit, SimpleChanges } from '@angular/core';
import { AllowableOperationsEnum } from '../../common/models/allowable-operations.enum';
import { Node } from '@alfresco/js-api';
import { Subject } from 'rxjs';
import { PermissionModel } from '../../document-list/models/permissions.model';
import { UploadBase } from './base-upload/upload-base';
import { NodeAllowableOperationSubject } from '../../interfaces/node-allowable-operation-subject.interface';
import * as i0 from "@angular/core";
export declare class UploadButtonComponent extends UploadBase implements OnInit, OnChanges, NodeAllowableOperationSubject {
    private contentService;
    private nodesApiService;
    protected logService: LogService;
    /** Allows/disallows upload folders (only for Chrome). */
    uploadFolders: boolean;
    /** Allows/disallows multiple files */
    multipleFiles: boolean;
    /** Defines the text of the upload button. */
    staticTitle: string;
    /** Custom tooltip text. */
    tooltip: string;
    /** Custom added file. The upload button type will be 'button' instead of 'file' */
    file: File;
    /** Emitted when create permission is missing. */
    permissionEvent: EventEmitter<PermissionModel>;
    private hasAllowableOperations;
    protected permissionValue: Subject<boolean>;
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    isButtonDisabled(): boolean;
    onFilesAdded($event: any): void;
    onClickUploadButton(): void;
    onDirectoryAdded($event: any): void;
    checkPermission(): void;
    nodeHasPermission(node: Node, permission: AllowableOperationsEnum | string): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<UploadButtonComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UploadButtonComponent, "adf-upload-button", never, { "uploadFolders": "uploadFolders"; "multipleFiles": "multipleFiles"; "staticTitle": "staticTitle"; "tooltip": "tooltip"; "file": "file"; }, { "permissionEvent": "permissionEvent"; }, never, never, false>;
}
