/*!
 * @license
 * Copyright © 2005-2023 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { AlfrescoApiService } from '@alfresco/adf-core';
import { OnChanges, EventEmitter, OnInit, OnDestroy } from '@angular/core';
import { VersionsApi, Node, VersionEntry, NodesApi, NodeEntry, ContentApi, ContentPagingQuery } from '@alfresco/js-api';
import { MatDialog } from '@angular/material/dialog';
import { ContentVersionService } from './content-version.service';
import { ContentService } from '../common/services/content.service';
import { InfiniteScrollDatasource } from '../infinite-scroll-datasource';
import { Observable } from 'rxjs';
import { CdkVirtualScrollViewport } from '@angular/cdk/scrolling';
import * as i0 from "@angular/core";
export declare class VersionListDataSource extends InfiniteScrollDatasource<VersionEntry> {
    private versionsApi;
    private node;
    constructor(versionsApi: VersionsApi, node: Node);
    getNextBatch(pagingOptions: ContentPagingQuery): Observable<VersionEntry[]>;
}
export declare class VersionListComponent implements OnChanges, OnInit, OnDestroy {
    private alfrescoApi;
    private contentService;
    private contentVersionService;
    private dialog;
    private onDestroy$;
    private _contentApi;
    get contentApi(): ContentApi;
    private _versionsApi;
    get versionsApi(): VersionsApi;
    private _nodesApi;
    get nodesApi(): NodesApi;
    versionsDataSource: VersionListDataSource;
    latestVersion: VersionEntry;
    isLoading: boolean;
    /** The target node. */
    node: Node;
    /** Toggles showing/hiding of comments */
    showComments: boolean;
    /** Enable/disable downloading a version of the current node. */
    allowDownload: boolean;
    /** Enable/disable viewing a version of the current node. */
    allowViewVersions: boolean;
    /** Toggles showing/hiding of version actions */
    showActions: boolean;
    /** Emitted when a version is restored */
    restored: EventEmitter<Node>;
    /** Emitted when a version is deleted */
    deleted: EventEmitter<Node>;
    /** Emitted when viewing a version */
    viewVersion: EventEmitter<string>;
    viewport: CdkVirtualScrollViewport;
    constructor(alfrescoApi: AlfrescoApiService, contentService: ContentService, contentVersionService: ContentVersionService, dialog: MatDialog);
    ngOnInit(): void;
    ngOnChanges(): void;
    ngOnDestroy(): void;
    canUpdate(): boolean;
    canDelete(): boolean;
    restore(versionId: string): void;
    onViewVersion(versionId: string): void;
    loadVersionHistory(): void;
    downloadVersion(versionId: string): void;
    deleteVersion(versionId: string): void;
    onVersionDeleted(node: any): void;
    onVersionRestored(node: NodeEntry): void;
    downloadContent(url: string): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<VersionListComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<VersionListComponent, "adf-version-list", never, { "node": "node"; "showComments": "showComments"; "allowDownload": "allowDownload"; "allowViewVersions": "allowViewVersions"; "showActions": "showActions"; }, { "restored": "restored"; "deleted": "deleted"; "viewVersion": "viewVersion"; }, never, never, false>;
}
