/*!
 * @license
 * Copyright © 2005-2023 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { EventEmitter, OnInit } from '@angular/core';
import { Node } from '@alfresco/js-api';
import { VersionListComponent } from './version-list.component';
import { ContentService } from '../common/services/content.service';
import { NodesApiService } from '../common/services/nodes-api.service';
import { FileUploadErrorEvent } from '../common/events/file.event';
import * as i0 from "@angular/core";
export declare class VersionManagerComponent implements OnInit {
    private contentService;
    private nodesApiService;
    /** Target node to manage version history. */
    node: Node;
    /** New file for updating current version. */
    newFileVersion: File;
    /** Toggles showing/hiding of comments. */
    showComments: boolean;
    /** Toggles showing/hiding the version comparison component. */
    showVersionComparison: boolean;
    /** Enable/disable downloading a version of the current node. */
    allowDownload: boolean;
    /** Emitted when a file is uploaded successfully. */
    uploadSuccess: EventEmitter<Node>;
    /** Emitted when an error occurs during upload. */
    uploadError: EventEmitter<FileUploadErrorEvent>;
    /** Emitted when an cancelling during upload. */
    uploadCancel: EventEmitter<boolean>;
    /** Emitted when viewing a version. */
    viewVersion: EventEmitter<string>;
    versionListComponent: VersionListComponent;
    uploadState: string;
    constructor(contentService: ContentService, nodesApiService: NodesApiService);
    ngOnInit(): void;
    refresh(node: Node): void;
    onUploadSuccess(event: any): void;
    onUploadError(event: FileUploadErrorEvent): void;
    onUploadCancel(): void;
    onViewVersion(versionId: string): void;
    toggleNewVersion(): void;
    canUpdate(): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<VersionManagerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<VersionManagerComponent, "adf-version-manager", never, { "node": "node"; "newFileVersion": "newFileVersion"; "showComments": "showComments"; "showVersionComparison": "showVersionComparison"; "allowDownload": "allowDownload"; }, { "uploadSuccess": "uploadSuccess"; "uploadError": "uploadError"; "uploadCancel": "uploadCancel"; "viewVersion": "viewVersion"; }, never, never, false>;
}
