/*!
 * @license
 * Copyright © 2005-2023 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { AlfrescoApiService, LogService } from '@alfresco/adf-core';
import { EventEmitter, OnChanges } from '@angular/core';
import { WebscriptApi } from '@alfresco/js-api';
import * as i0 from "@angular/core";
/**
 * @deprecated Webscript component has never been turned into a product and has no UI/UX and no use cases in ACA/ADW/ACC.
 */
export declare class WebscriptComponent implements OnChanges {
    private apiService;
    private logService;
    _webscriptApi: WebscriptApi;
    get webscriptApi(): WebscriptApi;
    /** (required) Path to the webscript (as defined by webscript). */
    scriptPath: string;
    /** Arguments to pass to the webscript. */
    scriptArgs: any;
    /** Toggles whether to show or hide the data. */
    showData: boolean;
    /** Path where the application is deployed */
    contextRoot: string;
    /** Path that the webscript service is mapped to. */
    servicePath: string;
    /**
     * Content type to interpret the data received from the webscript.
     * Can be "JSON" , "HTML" , "DATATABLE" or "TEXT"
     */
    contentType: string;
    /**
     * Emitted when the operation succeeds. You can get the plain data from
     * the webscript through the **success** event parameter and use it as you
     * need in your application.
     */
    success: EventEmitter<any>;
    data: any;
    showError: boolean;
    constructor(apiService: AlfrescoApiService, logService: LogService);
    ngOnChanges(): Promise<void>;
    /**
     * show the data in a ng2-alfresco-datatable
     *
     * @param data data
     * @returns the data as datatable
     */
    showDataAsDataTable(data: any): any;
    clean(): void;
    isDataTableContent(): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<WebscriptComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<WebscriptComponent, "adf-webscript-get", never, { "scriptPath": "scriptPath"; "scriptArgs": "scriptArgs"; "showData": "showData"; "contextRoot": "contextRoot"; "servicePath": "servicePath"; "contentType": "contentType"; }, { "success": "success"; }, never, never, false>;
}
